#!/bin/sh
ifconfig bnep0 0.0.0.0 down
#/sbin/ifdown bnep0
kill `cat /var/run/bt_tethering.pid`
rm /var/run/bt_tethering.pid
run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Bluetooth PAN Deactivated'
